@@ -15,7 +15,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
+from typing import Any, Dict, IO, List, TYPE_CHECKING, Type, Union, overload
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_secretsmanager.paginator import ListSecretsPaginator
 from mypy_boto3_secretsmanager.type_defs import (
@@ -86,7 +86,7 @@ class SecretsManagerClient:
         ClientRequestToken: str = None,
         Description: str = None,
         KmsKeyId: str = None,
-        SecretBinary: bytes = None,
+        SecretBinary: Union[bytes, IO[bytes]] = None,
         SecretString: str = None,
         Tags: List["TagTypeDef"] = None,
     ) -> CreateSecretResponseTypeDef:
@@ -181,7 +181,7 @@ class SecretsManagerClient:
         self,
         SecretId: str,
         ClientRequestToken: str = None,
-        SecretBinary: bytes = None,
+        SecretBinary: Union[bytes, IO[bytes]] = None,
         SecretString: str = None,
         VersionStages: List[str] = None,
     ) -> PutSecretValueResponseTypeDef:
@@ -221,7 +221,7 @@ class SecretsManagerClient:
         ClientRequestToken: str = None,
         Description: str = None,
         KmsKeyId: str = None,
-        SecretBinary: bytes = None,
+        SecretBinary: Union[bytes, IO[bytes]] = None,
         SecretString: str = None,
     ) -> UpdateSecretResponseTypeDef:
         """
