@@ -3,13 +3,15 @@ Main interface for secretsmanager service type definitions.
 
 Usage::
 
-    from mypy_boto3.secretsmanager.type_defs import RotationRulesTypeTypeDef
+    ```python
+    from mypy_boto3_secretsmanager.type_defs import RotationRulesTypeTypeDef
 
     data: RotationRulesTypeTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
-from typing import Dict, IO, List, Union
+from typing import Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -132,7 +134,7 @@ GetSecretValueResponseTypeDef = TypedDict(
         "ARN": str,
         "Name": str,
         "VersionId": str,
-        "SecretBinary": Union[bytes, IO],
+        "SecretBinary": bytes,
         "SecretString": str,
         "VersionStages": List[str],
         "CreatedDate": datetime,
